@@ -1,9 +1,6 @@
 //! Raw FFI bindings to the Android NDK.
 //!
 //! The bindings are pre-generated and the right one for the platform is selected at compile time.
-//!
-//! If you are including `android_native_app_glue.c`, the [`android_native_app_glue`
-//! module](android_native_app_glue/index.html) contains the interface for that.
 
 // Bindgen lints
 #![allow(non_upper_case_globals)]
@@ -17,6 +14,7 @@
 #![allow(deref_nullptr)]
 // Test setup lints
 #![cfg_attr(test, allow(dead_code))]
+#![cfg_attr(docsrs, feature(doc_cfg, doc_auto_cfg))]
 
 use jni_sys::*;
 
@@ -50,6 +48,6 @@ extern "C" {}
 #[link(name = "jnigraphics")]
 extern "C" {}
 
-#[cfg(all(feature = "aaudio", target_os = "android"))]
+#[cfg(all(feature = "audio", target_os = "android"))]
 #[link(name = "aaudio")]
 extern "C" {}
